@@ -23,7 +23,16 @@ class SummaryStatisticLoss(torch.nn.Module):
         Parameters
         ----------
         summary_statistic : str
-            Indicates which summary statistic function to use.
+            Indicates which summary statistic function to use. Must be
+            a summary statistics function that exists in the utilities
+            module, i.e. :mod:`torch_topological.utils`.
+
+            At present, the following choices are valid:
+
+            - `torch_topological.utils.persistent_entropy`
+            - `torch_topological.utils.polynomial_function`
+            - `torch_topological.utils.total_persistence`
+            - `torch_topological.utils.p_norm`
 
         **kwargs
             Optional keyword arguments, to be passed to the
@@ -63,23 +72,23 @@ class SummaryStatisticLoss(torch.nn.Module):
             In case no target tensor `Y` has been provided, the latter part
             of the expression amounts to `0`.
         """
-        stat_src = torch.sum(
-            torch.stack([
-                self.stat_fn(pi.diagram, **self.kwargs) for pi in X
-            ])
-        )
+        stat_src = self._evaluate_stat_fn(X)
 
         if Y is not None:
-            stat_target = torch.sum(
-                torch.stack([
-                    self.stat_fn(pi.diagram, **self.kwargs) for pi in Y
-                ])
-            )
-
+            stat_target = self._evaluate_stat_fn(Y)
             return (stat_target - stat_src).abs().pow(self.p)
         else:
             return stat_src.abs().pow(self.p)
 
+    def _evaluate_stat_fn(self, X):
+        """Evaluate statistic function for a given tensor."""
+        return torch.sum(
+            torch.stack([
+                self.stat_fn(pers_info.diagram, **self.kwargs)
+                for pers_info in X
+            ])
+        )
+
 
 class SignatureLoss(torch.nn.Module):
     """Implement topological signature loss.
@@ -158,15 +167,8 @@ class SignatureLoss(torch.nn.Module):
             for dim in self.dimensions
         ]
 
-        XY_dist = [
-            0.5 * torch.linalg.vector_norm(XX - YX, ord=self.p)
-            for XX, YX in zip(X_sig_X, Y_sig_X)
-        ]
-
-        YX_dist = [
-            0.5 * torch.linalg.vector_norm(YY - XY, ord=self.p)
-            for YY, XY in zip(Y_sig_Y, X_sig_Y)
-        ]
+        XY_dist = self._partial_distance(X_sig_X, Y_sig_X)
+        YX_dist = self._partial_distance(Y_sig_Y, X_sig_Y)
 
         return torch.stack(XY_dist).sum() + torch.stack(YX_dist).sum()
 
@@ -191,3 +193,16 @@ class SignatureLoss(torch.nn.Module):
             )
 
         return selected_distances
+
+    def _partial_distance(self, A, B):
+        """Calculate partial distances between pairings.
+
+        The purpose of this function is to calculate a partial distance
+        for the loss, depending on distances selected from the pairing.
+        """
+        dist = [
+            0.5 * torch.linalg.vector_norm(a - b, ord=self.p)
+            for a, b in zip(A, B)
+        ]
+
+        return dist
